navigation/route_snapshot library

Classes

RouteSnapshot
The pixels of the page that was on screen when a route change started.
RouteSnapshotScope
Exposes the RouteSnapshot a SlickPageHost is currently showing to the widgets on that page. Null when no snapshot is being shown.
SlickPageHost
Wraps the content of a SlickRoute page.