FeatureAccessController class

Properties

currentDetails FeatureAccessDetails?
getter/setter pair
getAvailableAccess Future<FeatureAccessDetails> Function()
final
hashCode int
The hash code for this object.
no setterinherited
onError FutureOr<void> Function(Object error)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

hasPermission(String pathName) bool
hasReadOnlyPermission(String pathName) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshAvailableAccess() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance FeatureAccessController
no setter

Static Methods

initialise(Future<FeatureAccessDetails> getAvailableAccess(), {FutureOr<void> onError(Object error)?}) Future<FeatureAccessController>