BoundsMessageBuilder<V> typedef

BoundsMessageBuilder<V> = String Function(BoundsViolation violation, V? min, V? max)

Builds a custom error message for a failed bounds check.

violation indicates which bound was broken; validators that only ever have one failure mode (e.g. RangeValidator with only min set) can ignore it.

Implementation

typedef BoundsMessageBuilder<V> = String Function(
  BoundsViolation violation,
  V? min,
  V? max,
);