BoundsViolation enum

Which bound a value violated, passed to a BoundsMessageBuilder.

Inheritance
Available extensions

Values

belowMin → const BoundsViolation

The value was below (or shorter/earlier than) BoundedFieldValidator.min.

aboveMax → const BoundsViolation

The value was above (or longer/later than) BoundedFieldValidator.max.

outsideRange → const BoundsViolation

Both BoundedFieldValidator.min and BoundedFieldValidator.max are set, and the value falls outside that range.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BoundsViolation>
A constant List of the values in this enum, in order of their declaration.