CombinedFieldValidator<T> class

A validator that combines multiple validators.

Inheritance

Constructors

CombinedFieldValidator(List<FieldValidator<T>> validators, {String? errorMessage})
When set, replaces the message of whichever child validators fails first, collapsing the group into a single message.

Properties

errorMessage String?
Overrides this validator's default error message.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validators List<FieldValidator<T>>
final

Methods

call(T? value) String?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveErrorMessage(String defaultMessage) String
Resolves the message to report for a failed validation.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited