CombinedFieldValidator<T> constructor

CombinedFieldValidator<T>(
  1. List<FieldValidator<T>> validators, {
  2. String? errorMessage,
})

When set, replaces the message of whichever child validators fails first, collapsing the group into a single message.

Implementation

CombinedFieldValidator(this.validators, {super.errorMessage});