FieldMatchMessageBuilder typedef
Builds a custom error message for a failed FieldMatchValidator check.
Implementation
typedef FieldMatchMessageBuilder = String Function(String fieldName);
Builds a custom error message for a failed FieldMatchValidator check.
typedef FieldMatchMessageBuilder = String Function(String fieldName);