FieldMatchValidator<T> class

A validator for checking if a value matches another field's value.

Inheritance

Constructors

FieldMatchValidator(String fieldName, T getFieldValue(), {String? errorMessage, FieldMatchMessageBuilder? errorMessageBuilder})

Properties

errorMessage String?
Overrides this validator's default error message.
finalinherited
errorMessageBuilder FieldMatchMessageBuilder?
Overrides this validator's default error message, with access to fieldName. Takes precedence over errorMessage.
final
fieldName String
final
getFieldValue → T Function()
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(T? value) String?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveErrorMessage(String defaultMessage) String
Resolves the message to report for a failed validation.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited