FieldValidator<T> class abstract

A generic abstract class representing a field validator.

Subclasses should implement the call method to define custom validation logic.

Implementers

Constructors

FieldValidator({String? errorMessage})

Properties

errorMessage String?
Overrides this validator's default error message.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(T? value) String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveErrorMessage(String defaultMessage) String
Resolves the message to report for a failed validation.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited