RangeValidator class

A validator for checking if a numeric value falls within a specified range.

Inheritance

Constructors

RangeValidator({num? min, num? max, String? errorMessage, BoundsMessageBuilder<num>? errorMessageBuilder})

Properties

errorMessage String?
Overrides this validator's default error message.
finalinherited
errorMessageBuilder BoundsMessageBuilder<num>?
Overrides this validator's default error message, with access to BoundsViolation, min and max. Takes precedence over errorMessage.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
max num?
finalinherited
min num?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(num? value) String?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveBoundsError(BoundsViolation violation, String defaultMessage()) String
Resolves the message to report for a failed bounds check.
inherited
resolveErrorMessage(String defaultMessage) String
Resolves the message to report for a failed validation.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited