useSnapshotLoading property
Whether route changes made through this class keep a screenshot of the current page on screen while the destination's view model initialises.
When true, SlickRoute pages are built without a page transition (the
snapshot is the transition) and are wrapped in a SlickPageHost.
Route changes not made through this class, such as the browser's back
button, cannot be captured and show the destination's loading widget.
Implementation
final bool useSnapshotLoading;