SlickRoute class abstract
The base route to extend when defining routes in a Slick application
Constructors
- SlickRoute()
-
const
Properties
-
filteredMenuItems
→ List<
NavigationItem> ? -
Get menuItems filtered by Feature Access Controller
no setter
-
filteredTabItems
→ List<
NavigationItem> ? -
Get tabItems filtered by Feature Access Controller
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- location → String
-
The location of this route, e.g. /family/f2/person/p1
no setterinherited
-
Override menuItems to set per-route menu items
no setter
- previousPath → SlickRoute?
-
Override previousPath to put a route other than this on the history stack when navigating
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tabItems
→ List<
NavigationItem> ? -
Override tabItems to set per-route tab items
no setter
Methods
-
build(
BuildContext context, GoRouterState state) → Widget -
Creates the Widget for
thisroute.inherited -
buildPage(
BuildContext context, GoRouterState state) → Page< void> -
A page builder for this route.
inherited
-
go(
BuildContext context) → void -
Navigate to the route.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onExit(
BuildContext context, GoRouterState state) → FutureOr< bool> -
Called when this route is removed from GoRouter's route history.
inherited
-
onRedirect(
BuildContext context, GoRouterState state) → FutureOr< String?> - Redirection logic: Return null if you do not want to redirect
-
push<
T> (BuildContext context) → Future< T?> -
Push the route onto the page stack.
inherited
-
pushReplacement(
BuildContext context) → void -
Replaces the top-most page of the page stack with the route.
inherited
-
redirect(
BuildContext context, GoRouterState state) → FutureOr< String?> - Do not override this; set onRedirect instead.
-
replace(
BuildContext context) → void -
Replaces the top-most page of the page stack with the route but treats
it as the same page.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override