EmailFieldValidator class
A validator for checking if a value is a valid email address.
- Inheritance
-
- Object
- FieldValidator<
String> - EmailFieldValidator
Constructors
- EmailFieldValidator({String? errorMessage})
Properties
- errorMessage → String?
-
Overrides this validator's default error message.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
String? value) → String? -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolveErrorMessage(
String defaultMessage) → String -
Resolves the message to report for a failed validation.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited